# casadata
Runtime data necessary for CASA operation

The Python package installs with an empty ```__data__``` subdirectory. The
contents must be populated by calling ```pull_data()``` to download the tables
from the Github repo ```data``` folder.

